Learn R Programming

repec (version 0.1.0)

getauthorshortid: Get Short-ID and name from string in name or email

Description

Get Short-ID and name from string in name or email

Usage

getauthorshortid(x, code = NA)

get_author_short_id(x, code = NA)

Arguments

x

string.

code

User code required to use API. Included in every API call. If not supplied, the REPEC_API_KEY environment variable will be used.

Value

data.frame

Examples

Run this code
# NOT RUN {
getauthorshortid('christian', code = YOURCODE)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab